@@ -33,7 +33,7 @@ data.Normalization<-function(x, type="n0")
 				n2=cbind(resul, (x[,nn] - median(x[,nn]))/(mad(x[,nn]))),
 				n3=cbind(resul, (x[,nn] - mean(x[,nn]))/(max(x[,nn]) - min(x[,nn]))),
 				n4=cbind(resul, (x[,nn] - min(x[,nn]))/(max(x[,nn]) - min(x[,nn]))),
-				n5=cbind(resul, (x[,nn] - mean(x[,nn]))/(max(abs(x[,nn]) - mean(x[,nn])))),
+				n5=cbind(resul, (x[,nn] - mean(x[,nn]))/(max(abs(x[,nn] - mean(x[,nn]))))),
 				n6=cbind(resul, (x[,nn])/ sd(x[,nn])),
 				n7=cbind(resul, (x[,nn])/(max(x[,nn]) - min(x[,nn]))),
 				n8=cbind(resul, (x[,nn])/(max(x[,nn]))),
@@ -63,7 +63,7 @@ data.Normalization<-function(x, type="n0")
 				n2=cbind(resul, (x[, i] - median(x[, i]))/(mad(x[, i]))),
 				n3=cbind(resul, (x[, i] - mean(x[, i]))/(max(x[, i]) - min(x[, i]))),
 				n4=cbind(resul, (x[, i] - min(x[, i]))/(max(x[, i]) - min(x[, i]))),
-				n5=cbind(resul, (x[, i] - mean(x[, i]))/(max(abs(x[, i]) - mean(x[, i])))),
+				n5=cbind(resul, (x[, i] - mean(x[, i]))/(max(abs(x[, i] - mean(x[, i]))))),
 				n6=cbind(resul, (x[, i])/ sd(x[, i])),
 				n7=cbind(resul, (x[, i])/(max(x[, i]) - min(x[, i]))),
 				n8=cbind(resul, (x[, i])/(max(x[, i]))),
